find_block

Function find_block 

pub fn find_block(
    content: &str,
    markers: &BlockMarkers,
) -> Option<(usize, usize)>
Find the byte range of a managed block in the content.

Returns Some((start, end)) where the range includes the begin marker, all content, and the end marker (including its trailing newline if present).