upsert_block

Function upsert_block 

pub fn upsert_block(
    content: &str,
    markers: &BlockMarkers,
    block: &str,
) -> String
Insert or replace a managed block in the content.

If the block already exists, it is replaced. Otherwise, it is appended with a blank separator line.