pub fn wait_with_timeout(
child: &mut Child,
timeout: Duration,
) -> Result<TimeoutResult<ExitStatus>>Expand description
Wait for a child process to exit, or return TimedOut after timeout
elapses. On timeout, the caller is responsible for killing the child.