remove_block

Function remove_block 

pub fn remove_block(
    content: &str,
    markers: &BlockMarkers,
) -> (String, BlockRemoveResult)
Remove a managed block from the content.

Returns the content with the block removed and excessive blank lines cleaned up. Returns unchanged content if the block is not found.